<p align="center">
<img src="https://raw.githubusercontent.com/hygeos/geoclide/refs/heads/main/geoclide/img/geoclide_logo2.png" width="300">
</p>

------------------------------------------------

[![image](https://img.shields.io/pypi/v/geoclide.svg)](https://pypi.python.org/pypi/geoclide)
[![image](https://img.shields.io/conda/vn/conda-forge/geoclide.svg)](https://anaconda.org/conda-forge/geoclide)
[![image](https://img.shields.io/github/v/tag/hygeos/geoclide?label=github&color=blue)](https://github.com/hygeos/geoclide)
[![image](https://pepy.tech/badge/geoclide)](https://pepy.tech/project/geoclide)

A python package for geometric calculations in the three-dimentional Euclidian space

Mustapha Moulana  
[HYGEOS website](https://hygeos.com/en/)  
[Documentation](https://hygeos.github.io/geoclide/)

-----------------------------------------

# Installation
The installation can be performed using one of the following commands:
```shell
$ conda install -c conda-forge geoclide
```
```shell
$ pip install geoclide
```
```shell
$ pip install git+https://github.com/hygeos/geoclide.git
```

# Testing
Run the command `pytest geoclide/tests/ -s -v` to check that everything is running correctly.


